/*
 ATtiny25 Basic VCO
 Version: 1.1
 Author: Alex from insideGadgets (http://www.insidegadgets.com)
 Created: 10/06/2013
 Last Modified: 10/06/2013
 
 Use a two 10K pots to adjust the frequency of the output ranging from 8Hz to 32MHz. 
 At the higher end it jumps in fairly large steps.
 
 */

#define F_CPU 1000000

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "setup.c"

// ATtiny25/45/85 Pin map
//
//                          +-\/-+
//              Reset PB5  1|o   |8  VCC
//    10K Pot Compare PB3  2|    |7  PB2
//  10K Pot Prescaler PB4  3|    |6  PB1 Output
//                    GND  4|    |5  PB0
//                          +----+

int main(void) {
	setup();
	
	while(1) {
		int compare = adcRead(3);
		OCR1A = (compare / 8); // Compare to
		OCR1C = ((compare / 8) * 2); // Set top
		_delay_ms(200);
		
		int prescaler = adcRead(2);
		TCCR1 = (TCCR1 & 0xF0) | (prescaler / 68); // Prescaler (0 to 15)
		_delay_ms(200);
	}
}
