/*
 ATtiny25 Basic VCO
 Version: 1.1
 Author: Alex from insideGadgets (http://www.insidegadgets.com)
 Created: 10/06/2013
 Last Modified: 10/06/2013
 
 */
 
#ifndef cbi
#define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~_BV(bit))
#endif
#ifndef sbi
#define sbi(sfr, bit) (_SFR_BYTE(sfr) |= _BV(bit))
#endif

#ifndef boolean
	typedef uint8_t boolean;
#endif
#ifndef bool
	typedef uint8_t bool;
#endif 
#ifndef byte
	typedef uint8_t byte;
#endif

#ifndef NULL
#define NULL ((void *)0)
#endif

#define LOW 0
#define HIGH 1
#define false 0
#define true 1

// Read from ADC
int adcRead(uint8_t adc) {
	uint8_t low, high;
	
	// set the analog reference as 1.1V and channel
	ADMUX = (adc & 0x3f);
	
	// start the conversion
	sbi(ADCSRA, ADSC);
	
	// ADSC is cleared when the conversion finishes
	while (bit_is_set(ADCSRA, ADSC));
	
	// Read results
	low = ADCL;
	high = ADCH;
	
	// combine the two bytes
	return (high << 8) | low;
}

void setup(void) {
	// PLL Enable
	sbi(PLLCSR, PLLE);
	_delay_ms(10);
	
	// PCK Enable
	sbi(PLLCSR, PCKE);
	
	// Set ouput
	DDRB |= (1<<PB1);
	
	// Set to 32MHz by default
	OCR1A = 0;
	OCR1C = 0;
	sbi(TCCR1, COM1A0);
	sbi(TCCR1, CTC1);
	sbi(TCCR1, CS10);
	
	// Set ADC prescale factor to 8
	// 1 MHz / 8 = 125 KHz, inside the desired 50-200 KHz range.
	sbi(ADCSRA, ADPS1);
	sbi(ADCSRA, ADPS0);
	
	// Enable ADC conversions
	sbi(ADCSRA, ADEN);
}
